@@ -6,7 +6,7 @@ from discord.abc import GuildChannel
 from discord.colour import Colour
 from discord.ext.commands import Context
 
-from dpymenus.constants import DENY
+from dpymenus.constants import QUIT
 from dpymenus.exceptions import PagesError
 from dpymenus.page import Page
 
@@ -136,7 +136,7 @@ class BaseMenu:
 
     async def _is_cancelled(self) -> bool:
         """Checks input for a cancellation string. If there is a match, it calls the ``menu.cancel()`` method and returns True."""
-        if self.input.content in DENY:
+        if self.input.content in QUIT:
             await self.cancel()
             return True
         return False
